==> kdevplatform-1.6.90.tar.xz: kdevplatform-1.6.90/plugins/subversion/kdevsubversion.desktop.cmake <==
[Desktop Entry]
Type=Service
Icon=subversion
Exec=blubb
Comment=This plugin integrates subversion to KDevelop.
Comment[bg]=Тази приставка вгражда subversion в KDevelop.
Comment[bs]=Ovaj dodatak integriše subversion u KDevelopu.
Comment[ca]=Aquest connector integra subversion en KDevelop.
Comment[ca@valencia]=Este connector integra subversion en KDevelop.
Comment[da]=Dette plugin integrerer subversion med KDevelop.
Comment[de]=Dieses Modul integriert Subversion in KDevelop.
Comment[el]=Αυτό το πρόσθετο ενσωματώνει το subversion στο KDevelop
Comment[en_GB]=This plugin integrates subversion to KDevelop.
Comment[es]=Este complemento integra «Subversion» en KDevelop.
Comment[et]=See plugin lõimib Subversioni KDeveloppi.
Comment[fi]=Tämä liitännäinen integroi subversion-ohjelman KDevelop-ympäristöön
Comment[fr]=Ce module externe intègre Subversion à KDevelop.
Comment[gl]=Este complemento integra subversion en KDevelop.
Comment[hu]=Ez a bővítmény integrálja a subversiont a KDevelopba.
Comment[it]=Questa estensione integra subversion in KDevelop.
Comment[ja]=このプラグインは Subversion を KDevelop に統合します
Comment[kk]=Бұл subversion-ды KDevelop-пен біріктіретін плагині.
Comment[lv]=Šis spraudnis integrē SVN iekš KDevelop.
Comment[nb]=Dette programtillegget integrerer subversion i KDevelop.
Comment[nds]=Dit Moduul bett Subversion na KDevelop in
Comment[nl]=Deze plugin integreert subversion in KDevelop.
Comment[pl]=Ta wtyczka udostępnia Subversion w KDevelopie
Comment[pt]=Este 'plugin' integra o Subversion com o KDevelop.
Comment[pt_BR]=Esta extensão integra o Subversion ao KDevelop.
Comment[ro]=Acest modul integrează subversion în KDevelop
Comment[ru]=Это расширение интегрирует в KDevelop поддержку Subversion.
Comment[sk]=Tento plugin integruje subversion do KDevelop.
Comment[sl]=Vstavek v KDevelop vgradi Subversion.
Comment[sv]=Insticksprogrammet integrerar Subversion i KDevelop
Comment[tr]=Bu eklenti Subversion ile KDevelop uygulamasını bütünleştirir
Comment[uk]=За допомогою цього додатка можна інтегрувати subversion (SVN) до KDevelop.
Comment[x-test]=xxThis plugin integrates subversion to KDevelop.xx
Comment[zh_CN]=此插件对 KDevelop 整合 subversion。
Comment[zh_TW]=此外掛程式將 subversion 整合進 KDevelop。
Name=Subversion Support
Name[bg]=Поддръжка на Subversion
Name[bs]=Podrška za subversion
Name[ca]=Implementació de Subversion
Name[ca@valencia]=Implementació de Subversion
Name[da]=Subversion-understøttelse
Name[de]=Subversion-Unterstützung
Name[el]=Υποστήριξη Subversion
Name[en_GB]=Subversion Support
Name[es]=Implementación de Subversion
Name[et]=Subversioni toetus
Name[fi]=Subversion-tuki
Name[fr]=Prise en charge de Subversion
Name[gl]=Soporte de Subversion
Name[hu]=Subversion támogatás
Name[it]=Supporto subversion
Name[ja]=Subversion サポート
Name[kk]=Subversion қолдауы
Name[nb]=Støtte for subversion
Name[nds]=Subversion-Ünnerstütten
Name[nl]=Ondersteuning van subversion
Name[pa]=ਸਬਵਰਜਨ ਸਹਿਯੋਗ
Name[pl]=Obsługa Subversion
Name[pt]=Suporte para Subversion
Name[pt_BR]=Suporte ao Subversion
Name[ru]=Поддержка Subversion
Name[sk]=Podpora subversion
Name[sl]=Podpora za Subversion
Name[sv]=Stöd för Subversion
Name[tr]=Subversion Desteği
Name[ug]=Subversion قوللىشى
Name[uk]=Підтримка Subversion
Name[x-test]=xxSubversion Supportxx
Name[zh_CN]=Subversion 支持
Name[zh_TW]=Subversion 支援
GenericName=Version Control Support
GenericName[bg]=Поддръжка на управление на версиите
GenericName[bs]=Podrška za kontrolu verzija
GenericName[ca]=Implementació del control de versions
GenericName[ca@valencia]=Implementació del control de versions
GenericName[cs]=Podpora správy verzí
GenericName[da]=Understøttelse af versionstyring
GenericName[de]=Unterstützung für Versionsverwaltungssysteme
GenericName[el]=Υποστήριξη Version Control
GenericName[en_GB]=Version Control Support
GenericName[es]=Implementación de Control de Versiones
GenericName[et]=Versioonihalduse toetus
GenericName[fi]=Versionhallintatuki
GenericName[fr]=Prise en charge du contrôle de versions
GenericName[gl]=Soporte de sistemas de versións
GenericName[hu]=Verziókezelő támogatás
GenericName[it]=Supporto controllo versione
GenericName[ja]=バージョン管理のサポート
GenericName[kk]=Нұсқаларын қадағалауды қолдау
GenericName[nb]=Støtte for versjonskontroll 
GenericName[nds]=Verschoonkuntrull-Ünnerstütten
GenericName[nl]=Ondersteuning voor versiecontrole
GenericName[pl]=Obsługa kontroli wersji
GenericName[pt]=Suporte ao Controlo de Versões
GenericName[pt_BR]=Suporte a controle de versão
GenericName[ru]=Поддержка систем управления версиями
GenericName[sk]=Podpora správy verzií
GenericName[sl]=Podpora za nadzor različic
GenericName[sv]=Stöd för versionskontroll
GenericName[tr]=Sürüm Kontrol Desteği
GenericName[ug]=نەشر باشقۇرۇش قوللىشى
GenericName[uk]=Підтримка керування версіями
GenericName[x-test]=xxVersion Control Supportxx
GenericName[zh_CN]=版本控制支持
GenericName[zh_TW]=版本控制支援
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevsubversion
X-KDE-PluginInfo-Name=kdevsubversion
X-KDE-PluginInfo-Author=Dukju Ahn
X-KDE-PluginInfo-Version=0.1
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-Category=Version Control
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDevelop-Interfaces=org.kdevelop.IBasicVersionControl
X-KDevelop-IRequired=org.kdevelop.IOutputView
X-KDevelop-Mode=GUI

==> kdevplatform-1.7.4.tar.xz: kdevplatform-1.7.4/plugins/subversion/kdevsubversion.desktop.cmake <==
[Desktop Entry]
Type=Service
Icon=subversion
Exec=blubb
Comment=This plugin integrates subversion to KDevelop.
Comment[bg]=Тази приставка вгражда subversion в KDevelop.
Comment[bs]=Ovaj dodatak integriše subversion u KDevelopu.
Comment[ca]=Aquest connector integra el «subversion» en el KDevelop.
Comment[ca@valencia]=Este connector integra el «subversion» en el KDevelop.
Comment[da]=Dette plugin integrerer subversion med KDevelop.
Comment[de]=Dieses Modul integriert Subversion in KDevelop.
Comment[el]=Αυτό το πρόσθετο ενσωματώνει το subversion στο KDevelop
Comment[en_GB]=This plugin integrates subversion to KDevelop.
Comment[es]=Este complemento integra «Subversion» en KDevelop.
Comment[et]=See plugin lõimib Subversioni KDeveloppi.
Comment[fi]=Tämä liitännäinen integroi subversion-ohjelman KDevelop-ympäristöön
Comment[fr]=Ce module externe intègre Subversion à KDevelop.
Comment[gl]=Este complemento integra subversion en KDevelop.
Comment[hu]=Ez a bővítmény integrálja a subversiont a KDevelopba.
Comment[it]=Questa estensione integra subversion in KDevelop.
Comment[ja]=このプラグインは Subversion を KDevelop に統合します
Comment[kk]=Бұл subversion-ды KDevelop-пен біріктіретін плагині.
Comment[lv]=Šis spraudnis integrē SVN iekš KDevelop.
Comment[nb]=Dette programtillegget integrerer subversion i KDevelop.
Comment[nds]=Dit Moduul bett Subversion na KDevelop in
Comment[nl]=Deze plugin integreert subversion in KDevelop.
Comment[pl]=Ta wtyczka udostępnia Subversion w KDevelopie
Comment[pt]=Este 'plugin' integra o Subversion com o KDevelop.
Comment[pt_BR]=Esta extensão integra o Subversion ao KDevelop.
Comment[ro]=Acest modul integrează subversion în KDevelop
Comment[ru]=Это расширение интегрирует в KDevelop поддержку Subversion.
Comment[sk]=Tento plugin integruje subversion do KDevelop.
Comment[sl]=Vstavek v KDevelop vgradi Subversion.
Comment[sv]=Insticksprogrammet integrerar Subversion i KDevelop
Comment[tr]=Bu eklenti Subversion ile KDevelop uygulamasını bütünleştirir
Comment[uk]=За допомогою цього додатка можна інтегрувати subversion (SVN) до KDevelop.
Comment[x-test]=xxThis plugin integrates subversion to KDevelop.xx
Comment[zh_CN]=此插件对 KDevelop 整合 subversion。
Comment[zh_TW]=此外掛程式將 subversion 整合進 KDevelop。
Name=Subversion Support
Name[bg]=Поддръжка на Subversion
Name[bs]=Podrška za subversion
Name[ca]=Implementació del «subversion»
Name[ca@valencia]=Implementació del «subversion»
Name[cs]=Podpora subversion
Name[da]=Subversion-understøttelse
Name[de]=Subversion-Unterstützung
Name[el]=Υποστήριξη Subversion
Name[en_GB]=Subversion Support
Name[es]=Implementación de Subversion
Name[et]=Subversioni toetus
Name[fi]=Subversion-tuki
Name[fr]=Prise en charge de Subversion
Name[gl]=Soporte de Subversion
Name[hu]=Subversion támogatás
Name[it]=Supporto subversion
Name[ja]=Subversion サポート
Name[kk]=Subversion қолдауы
Name[nb]=Støtte for subversion
Name[nds]=Subversion-Ünnerstütten
Name[nl]=Ondersteuning van subversion
Name[pa]=ਸਬਵਰਜਨ ਸਹਿਯੋਗ
Name[pl]=Obsługa Subversion
Name[pt]=Suporte para Subversion
Name[pt_BR]=Suporte ao Subversion
Name[ru]=Поддержка Subversion
Name[sk]=Podpora subversion
Name[sl]=Podpora za Subversion
Name[sv]=Stöd för Subversion
Name[tr]=Subversion Desteği
Name[ug]=Subversion قوللىشى
Name[uk]=Підтримка Subversion
Name[x-test]=xxSubversion Supportxx
Name[zh_CN]=Subversion 支持
Name[zh_TW]=Subversion 支援
GenericName=Version Control Support
GenericName[bg]=Поддръжка на управление на версиите
GenericName[bs]=Podrška za kontrolu verzija
GenericName[ca]=Implementació del control de versions
GenericName[ca@valencia]=Implementació del control de versions
GenericName[cs]=Podpora správy verzí
GenericName[da]=Understøttelse af versionstyring
GenericName[de]=Unterstützung für Versionsverwaltungssysteme
GenericName[el]=Υποστήριξη Version Control
GenericName[en_GB]=Version Control Support
GenericName[es]=Implementación de Control de Versiones
GenericName[et]=Versioonihalduse toetus
GenericName[fi]=Versionhallintatuki
GenericName[fr]=Prise en charge du contrôle de versions
GenericName[gl]=Soporte de sistemas de versións
GenericName[hu]=Verziókezelő támogatás
GenericName[it]=Supporto controllo versione
GenericName[ja]=バージョン管理のサポート
GenericName[kk]=Нұсқаларын қадағалауды қолдау
GenericName[nb]=Støtte for versjonskontroll 
GenericName[nds]=Verschoonkuntrull-Ünnerstütten
GenericName[nl]=Ondersteuning voor versiecontrole
GenericName[pl]=Obsługa kontroli wersji
GenericName[pt]=Suporte ao Controlo de Versões
GenericName[pt_BR]=Suporte a controle de versão
GenericName[ru]=Поддержка систем управления версиями
GenericName[sk]=Podpora správy verzií
GenericName[sl]=Podpora za nadzor različic
GenericName[sv]=Stöd för versionskontroll
GenericName[tr]=Sürüm Kontrol Desteği
GenericName[ug]=نەشر باشقۇرۇش قوللىشى
GenericName[uk]=Підтримка керування версіями
GenericName[x-test]=xxVersion Control Supportxx
GenericName[zh_CN]=版本控制支持
GenericName[zh_TW]=版本控制支援
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevsubversion
X-KDE-PluginInfo-Name=kdevsubversion
X-KDE-PluginInfo-Author=Dukju Ahn
X-KDE-PluginInfo-Version=0.1
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-Category=Version Control
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDevelop-Interfaces=org.kdevelop.IBasicVersionControl
X-KDevelop-IRequired=org.kdevelop.IOutputView
X-KDevelop-Mode=GUI
